<?php
/**
 * Kid Toys Store functions and definitions
 *
 * @package Kid Toys Store
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'kid_toys_store_setup' ) ) :

/* Theme Setup */
function kid_toys_store_setup() {

	$GLOBALS['content_width'] = apply_filters( 'kid_toys_store_content_width', 640 );

	load_theme_textdomain( 'kid-toys-store', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('kid-toys-store-homepage-thumb',240,145,true);
	
       register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'kid-toys-store' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support(
		'post-formats', array(
			'image',
			'video',
			'gallery',
			'audio',
		)	
	);
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', kid_toys_store_font_url() ) );

	// Dashboard Theme Notification
	global $pagenow;
	
	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'kid_toys_store_activation_notice' );
	}	
}
endif;
add_action( 'after_setup_theme', 'kid_toys_store_setup' );

// Dashboard Theme Notification
function kid_toys_store_activation_notice() {
	echo '<div class="welcome-notice notice notice-success is-dismissible">';
		echo '<h2>'. esc_html__( 'Thank You!!!!!', 'kid-toys-store' ) .'</h2>';
		echo '<p>'. esc_html__( 'Much grateful to you for choosing our Kids Toys Store theme from themescaliber. we praise you for opting our services over others. we are obliged to invite you on our welcome page to render you with our outstanding services.', 'kid-toys-store' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=kid_toys_store_guide' ) ) .'" class="button button-primary">'. esc_html__( 'Click Here...', 'kid-toys-store' ) .'</a></p>';
	echo '</div>';
}

/* Theme Widgets Setup */
function kid_toys_store_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'kid-toys-store' ),
		'description'   => __( 'Appears on blog page sidebar', 'kid-toys-store' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'kid-toys-store' ),
		'description'   => __( 'Appears on page sidebar', 'kid-toys-store' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Thid Column Sidebar', 'kid-toys-store' ),
		'description'   => __( 'Appears on page sidebar', 'kid-toys-store' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Nav 1', 'kid-toys-store' ),
		'description'   => __( 'Appears on footer', 'kid-toys-store' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Nav 2', 'kid-toys-store' ),
		'description'   => __( 'Appears on footer', 'kid-toys-store' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Nav 3', 'kid-toys-store' ),
		'description'   => __( 'Appears on footer', 'kid-toys-store' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Nav 4', 'kid-toys-store' ),
		'description'   => __( 'Appears on footer', 'kid-toys-store' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'kid_toys_store_widgets_init' );

/* Theme Font URL */
function kid_toys_store_font_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'Kavoon';
	$font_family[] = 'Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}

/* Theme enqueue scripts */
function kid_toys_store_scripts() {
	wp_enqueue_style( 'kid-toys-store-font', kid_toys_store_font_url(), array() );	
	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css' );	
	wp_style_add_data( 'kid-toys-store-style', 'rtl', 'replace' );
	wp_enqueue_style( 'kid-toys-store-effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'kid-toys-store-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_style( 'css-nivo-slider', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'jquery-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );	
	wp_enqueue_script( 'kid-toys-store-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/* Enqueue the Dashicons script */
	wp_enqueue_style( 'dashicons' );
	wp_enqueue_style('kid-toys-store-ie', get_template_directory_uri().'/css/ie.css');
}
add_action( 'wp_enqueue_scripts', 'kid_toys_store_scripts' );

function kid_toys_store_sanitize_dropdown_pages( $page_id, $setting ) {
  // Ensure $input is an absolute integer.
  $page_id = absint( $page_id );
  // If $page_id is an ID of a published page, return it; otherwise, return the default.
  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/*radio button sanitization*/

 function kid_toys_store_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

// URL DEFINES
define('KID_TOYS_STORE_FREE_THEME_DOC','https://themescaliber.com/doc/free-kid-toys-store/','kid-toys-store');
define('KID_TOYS_STORE_SUPPORT','https://wordpress.org/support/theme/kid-toys-store/reviews/?filter=5','kid-toys-store');
define('KID_TOYS_STORE_REVIEW','https://www.themescaliber.com/topic/reviews-and-testimonials','kid-toys-store');
define('KID_TOYS_STORE_BUY_NOW','https://www.themescaliber.com/themes/premium-kids-wordpress-theme','kid-toys-store');
define('KID_TOYS_STORE_LIVE_DEMO','https://themescaliber.com/kid-toys-store-pro/','kid-toys-store');
define('KID_TOYS_STORE_PRO_DOC','https://themescaliber.com/doc/kid-toys-store-pro/','kid-toys-store');
define('KID_TOYS_STORE_CHILD_THEME','https://developer.wordpress.org/themes/advanced-topics/child-themes/','kid-toys-store');
define('KID_TOYS_STORE_DEMO_DATA','https://www.themescaliber.com/doc/kidtoys-store.xml.zip','kid-toys-store');
define('KID_TOYS_STORE_SITE_URL','https://www.themescaliber.com/');

function kid_toys_store_credit_link() {
    echo "<a href=".esc_url(KID_TOYS_STORE_SITE_URL)." target='_blank'>".esc_html('ThemesCaliber','kid-toys-store')."</a>";
}

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Implement the get started page */
require get_template_directory() . '/inc/dashboard/getstart.php';